library(lme4)
library(dplyr)
library(moments)
library(effects)

#set working directory

#read and name data file
VPTdata<-read.csv("VPT.csv", header = T)
head(VPTdata,3) 
summary(VPTdata)

#dim
VPTdata$culture <- as.factor(VPTdata$culture) 
VPTdata$subject <- as.factor(VPTdata$subject) 
VPTdata$persp <- as.factor(VPTdata$persp) 
VPTdata$consistency <- as.factor(VPTdata$consistency) 
VPTdata$item <- as.factor(VPTdata$item) 
VPTdata$acc <- as.numeric(VPTdata$acc) 
VPTdata$rt <- as.numeric(VPTdata$rt) 
VPTdata$cp <- as.factor(VPTdata$cp) 


#contrast coding: add columns with contrast coded IVs
VPTdata_stats=VPTdata %>%
  mutate(consis_contrast = ifelse(consistency == "consistent", -0.5, 0.5)) %>%
  mutate(culture_contrast = ifelse(culture == "TW", -0.5, 0.5)) %>%
  mutate(persp_contrast = ifelse(persp == "other", -0.5,0.5))

#check contrast coding
xtabs(~consistency+consis_contrast, VPTdata_stats)
xtabs(~culture+culture_contrast, VPTdata_stats)
xtabs(~persp+persp_contrast, VPTdata_stats)

#check within-between variables
xtabs(~subject+consis_contrast+persp_contrast, VPTdata_stats)
xtabs(~item+culture_contrast+persp_contrast, VPTdata_stats)

# Remove any incorrect responses for RT
VPTcorr<-subset(VPTdata_stats, acc==1, drop = FALSE)

#check removal
head(VPTcorr, 3)
summary(VPTcorr) 

#check RT distribution
hist(VPTcorr$rt)
qqnorm(VPTcorr$rt)
skewness(VPTcorr$rt, na.rm=TRUE) 
kurtosis(VPTcorr$rt, na.rm=TRUE) 


##rt
rtm1<-lmer(rt ~ consis_contrast*culture_contrast*persp_contrast + 
              (1+consis_contrast*persp_contrast|subject) + 
              (1+culture_contrast*persp_contrast|item), 
            data = VPTcorr, 
            REML=F) #converges
summary(rtm1)

rtm1_noconsis<-update(rtm1, .~. - consis_contrast)
anova(rtm1,rtm1_noconsis) 

rtm1_nocult<-update(rtm1, .~. - culture_contrast) #not converge

rtm2<-lmer(rt ~ consis_contrast*culture_contrast*persp_contrast + 
             (1+consis_contrast*persp_contrast||subject) + 
             (1+culture_contrast*persp_contrast||item), 
           data = VPTcorr, 
           REML=F)
summary(rtm2) #persp|item accounted for least variance

rtm3<-lmer(rt ~ consis_contrast*culture_contrast*persp_contrast + 
             (1+consis_contrast*persp_contrast|subject) + 
             (1+culture_contrast+persp_contrast:culture_contrast|item), 
           data = VPTcorr, 
           REML=F)
summary(rtm3)

rtm3_noconsis<-update(rtm3, .~. - consis_contrast)
anova(rtm3,rtm3_noconsis) 

rtm3_nocult<-update(rtm3, .~. - culture_contrast)
anova(rtm3,rtm3_nocult) 

rtm3_nopersp<-update(rtm3, .~. - persp_contrast)
anova(rtm3,rtm3_nopersp)

rtm3_noconsiscult<-update(rtm3, .~. - consis_contrast:culture_contrast)
anova(rtm3,rtm3_noconsiscult)

rtm3_noconsispersp<-update(rtm3, .~. - consis_contrast:persp_contrast) 
anova(rtm3,rtm3_noconsispersp)

rtm3_nocultpersp<-update(rtm3, .~. - culture_contrast:persp_contrast) 
anova(rtm3,rtm3_nocultpersp)

rtm3_no3way<-update(rtm3, .~. - consis_contrast:culture_contrast:persp_contrast) 
anova(rtm3,rtm3_no3way) 
BF_BIC = exp((BIC(rtm3_no3way) - BIC(rtm3))/2)  #BICs to Bayes factor
BF_BIC #BF10=0.0177


#follow up on consistency*persp interaction in RT 

#organise data by subject
data.sub<- aggregate(rt ~ subject + consistency*persp, VPTcorr, mean)
data.sub

# mean and SD for calculating cohen's d
data.subSD<- aggregate(rt ~ consistency*persp, VPTcorr, sd)
data.subSD
data.subM<- aggregate(rt ~ consistency*persp, VPTcorr, mean)
data.subM

#egocentric effect
t.testego<- t.test(subset(data.sub, consistency=="consistent" & persp=="other")$rt,
                subset(data.sub, consistency=="inconsistent" & persp=="other")$rt, paired=TRUE)
t.testego

#altercentric effect
t.testalt<- t.test(subset(data.sub, consistency=="consistent" & persp=="self")$rt,
                   subset(data.sub, consistency=="inconsistent" & persp=="self")$rt, paired=TRUE)
t.testalt

#consistent trials
t.testcon<- t.test(subset(data.sub, consistency=="consistent" & persp=="other")$rt,
                   subset(data.sub, consistency=="consistent" & persp=="self")$rt, paired=TRUE)
t.testcon

#inconsistent trials
t.testincon<- t.test(subset(data.sub, consistency=="inconsistent" & persp=="other")$rt,
                   subset(data.sub, consistency=="inconsistent" & persp=="self")$rt, paired=TRUE)
t.testincon


##acc
VPTaccm1 = glmer(acc ~ consis_contrast*culture_contrast*persp_contrast +  
                   (1+consis_contrast*persp_contrast|subject) + 
                   (1+culture_contrast*persp_contrast|item),  
                 family=binomial(link="logit"),
                 data = VPTdata_stats,
                 control=glmerControl(optimizer="bobyqa")) #not converge

VPTaccm2 = glmer(acc ~ consis_contrast*culture_contrast*persp_contrast +  
                   (1+consis_contrast*persp_contrast||subject) + 
                   (1+culture_contrast*persp_contrast||item),  
                 family=binomial(link="logit"),
                 data = VPTdata_stats,
                 control=glmerControl(optimizer="bobyqa")) #uncorrelate
summary(VPTaccm2) #culture|item accounted for least variance

VPTaccm3 = glmer(acc ~ consis_contrast*culture_contrast*persp_contrast +  
                   (1+consis_contrast*persp_contrast|subject) + 
                   (1+persp_contrast+culture_contrast:persp_contrast|item),  
                 family=binomial(link="logit"),
                 data = VPTdata_stats,
                 control=glmerControl(optimizer="bobyqa")) #not converge #remove cult*persp|item

VPTaccm4 = glmer(acc ~ consis_contrast*culture_contrast*persp_contrast +  
                   (1+consis_contrast*persp_contrast|subject) + 
                   (1+persp_contrast|item),  
                 family=binomial(link="logit"),
                 data = VPTdata_stats,
                 control=glmerControl(optimizer="bobyqa")) #not converge #remove consis*persp|subject

VPTaccm5 = glmer(acc ~ consis_contrast*culture_contrast*persp_contrast +  
                   (1+consis_contrast+persp_contrast|subject) + 
                   (1+persp_contrast|item),  
                 family=binomial(link="logit"),
                 data = VPTdata_stats,
                 control=glmerControl(optimizer="bobyqa")) #not converge #remove consis|subject

VPTaccm6 = glmer(acc ~ consis_contrast*culture_contrast*persp_contrast +  
                   (1+persp_contrast|subject) + 
                   (1+persp_contrast|item),  
                 family=binomial(link="logit"),
                 data = VPTdata_stats,
                 control=glmerControl(optimizer="bobyqa")) #converges
summary(VPTaccm6)

VPTaccm6_noconsis<-update(VPTaccm6, .~. - consis_contrast)
anova(VPTaccm6, VPTaccm6_noconsis) 

VPTaccm6_nocult<-update(VPTaccm6, .~. - culture_contrast)
anova(VPTaccm6, VPTaccm6_nocult) 

VPTaccm6_nopersp<-update(VPTaccm6, .~. - persp_contrast)
anova(VPTaccm6, VPTaccm6_nopersp)

VPTaccm6_noconsiscult<-update(VPTaccm6, .~. - consis_contrast:culture_contrast)
anova(VPTaccm6, VPTaccm6_noconsiscult) 

VPTaccm6_noperspcult<-update(VPTaccm6, .~. - persp_contrast:culture_contrast)
anova(VPTaccm6, VPTaccm6_noperspcult) 

VPTaccm6_noconsispersp<-update(VPTaccm6, .~. - consis_contrast:persp_contrast)
anova(VPTaccm6, VPTaccm6_noconsispersp) 

VPTaccm6_no3way<-update(VPTaccm6, .~. - consis_contrast:culture_contrast:persp_contrast)
anova(VPTaccm6, VPTaccm6_no3way)
BF_BIC = exp((BIC(VPTaccm6_no3way) - BIC(VPTaccm6))/2)  # BICs to Bayes factor
BF_BIC #BF10=0.0146
