install.package("lme4")
install.packages("dplyr")
install.packages("moments")
install.packages("effects")

library(lme4)
library(dplyr)
library(moments)
library(effects)

#set working directory

#read and name data file
s3data<-read.csv("s3data.csv", header = T)
head(s3data,3) 
summary(s3data)

#dim
s3data$subject <- as.factor(s3data$subject) 
s3data$condition <- as.factor(s3data$condition) 
s3data$persp <- as.factor(s3data$persp) 
s3data$item <- as.factor(s3data$item) 
s3data$culture <- as.factor(s3data$culture) 
s3data$llt <- as.numeric(s3data$llt) 
s3data$distrafix <- as.numeric(s3data$distrafix) 
s3data$rt <- as.numeric(s3data$rt) 
s3data$ego <- as.numeric(s3data$ego) 
s3data$acc <- as.numeric(s3data$acc) 

#contrast coding
s3data_stats=s3data %>%
  mutate(condition_contrast = ifelse(condition == "control", -0.5, 0.5)) %>%
  mutate(culture_contrast = ifelse(culture == "TW", -0.5, 0.5)) %>%
  mutate(persp_contrast = ifelse(persp == "female", -0.5,0.5))

#check contrast coding
xtabs(~condition+condition_contrast, s3data_stats)
xtabs(~culture+culture_contrast, s3data_stats)
xtabs(~persp+persp_contrast, s3data_stats)

#check within-between variables
xtabs(~subject+condition_contrast+persp_contrast, s3data_stats)
xtabs(~item+condition_contrast+culture_contrast, s3data_stats)

# Remove any incorrect responses for RT and LLT data set
data_acc_corr<-subset(s3data_stats, acc==1, drop = FALSE)

#check removal
head(data_acc_corr, 3)
summary(data_acc_corr) #all stats on acc= 1

#check RT distribution
hist(data_acc_corr$rt)
skewness(data_acc_corr$rt, na.rm=TRUE) 
kurtosis(data_acc_corr$rt, na.rm=TRUE) 

#see if log improves distribution
data_rt_log<-log(data_acc_corr$rt)
qqnorm(data_acc_corr$rt)
skewness(data_rt_log, na.rm=TRUE) 
kurtosis(data_rt_log, na.rm=TRUE) #not improved

#check LLT distribution
hist(data_acc_corr$llt)
qqnorm(data_acc_corr$llt)
skewness(data_acc_corr$llt, na.rm=TRUE) 
kurtosis(data_acc_corr$llt, na.rm=TRUE) 

#see if log improves distribution
data_llt_log<-log(data_acc_corr$llt)
skewness(data_llt_log, na.rm=TRUE)
kurtosis(data_llt_log, na.rm=TRUE) #not improved

##remove NA cases
s3data_stats$complete <- complete.cases(s3data_stats)
s3data_stats_nona <- subset(s3data_stats, complete == "TRUE") 


## RT
rt_m1<-lmer(rt ~ condition_contrast*culture_contrast*persp_contrast + 
              (1+condition_contrast*persp_contrast|subject) + 
              (1+condition_contrast*culture_contrast|item), 
            data = s3data_stats_nona, 
            REML=F) #not converge

rt_m2<-lmer(rt ~ condition_contrast*culture_contrast*persp_contrast + 
              (1+condition_contrast*persp_contrast|subject) + 
              (1+condition_contrast*culture_contrast||item), 
            data = s3data_stats_nona, 
            REML=F) #uncorrelate
summary(rt_m2)
#condition:culture|item accounts for the smallest amount of variance, so removed

rt_m3<-lmer(rt ~ condition_contrast*culture_contrast*persp_contrast + 
              (1+condition_contrast*persp_contrast|subject) + 
              (1+condition_contrast+culture_contrast|item),
            data = s3data_stats_nona, 
            REML=F) #converges
summary(rt_m3)

#main effect of condition
rt_m3_nocon<-lmer(rt ~ condition_contrast*culture_contrast*persp_contrast - condition_contrast + 
                    (1+condition_contrast*persp_contrast|subject) + 
                    (1+condition_contrast+culture_contrast|item),
                  data = s3data_stats_nona, 
                  REML=F) #not converge

rt_m31<-lmer(rt ~ condition_contrast*culture_contrast*persp_contrast + 
              (1+condition_contrast*persp_contrast|subject) + 
              (1 + culture_contrast|item),
            data = s3data_stats_nona, 
            REML=F) #further remove condition|item as account for smallest amount of variance, still have culture|item slope 

rt_m31_nocon<-lmer(rt ~ condition_contrast*culture_contrast*persp_contrast - condition_contrast + 
                    (1+condition_contrast*persp_contrast|subject) + 
                    (1 + culture_contrast|item),
                  data = s3data_stats_nona, 
                  REML=F)
anova(rt_m31,rt_m31_nocon)

rt_m31_nocult<-update(rt_m31, .~.- culture_contrast)
anova(rt_m31,rt_m31_nocult)

rt_m31_nopersp<-update(rt_m31, .~.- persp_contrast)
anova(rt_m31,rt_m31_nopersp)

rt_m31_noconcult<-update(rt_m31, .~.- condition_contrast:culture_contrast)
anova(rt_m31,rt_m31_noconcult) 

rt_m31_noconpersp<-update(rt_m31, .~.- condition_contrast:persp_contrast)
anova(rt_m31,rt_m31_noconpersp) 

rt_m31_nocultpersp<-update(rt_m31, .~.- culture_contrast:persp_contrast)
anova(rt_m31,rt_m31_nocultpersp) 

rt_m31_no3way<-update(rt_m31, .~.- condition_contrast:culture_contrast:persp_contrast)
anova(rt_m31,rt_m31_no3way)
BF_BIC = exp((BIC(rt_m31_no3way) - BIC(rt_m31))/2)  #BICs to Bayes factor
BF_BIC #BF10=0.0241


##LLT (latency to final target fixation)
llt_m1<-lmer(llt ~ condition_contrast*culture_contrast*persp_contrast + 
              (1+condition_contrast*persp_contrast|subject) + 
              (1+condition_contrast*culture_contrast|item), 
            data = s3data_stats_nona, 
            REML=F) #converges
summary(llt_m1)

llt_m1_nocon<-update(llt_m1, .~. - condition_contrast)
anova(llt_m1,llt_m1_nocon)

llt_m1_nocult<-update(llt_m1, .~. - culture_contrast)
anova(llt_m1,llt_m1_nocult) 

llt_m1_nopersp<-update(llt_m1, .~. - persp_contrast)
anova(llt_m1,llt_m1_nopersp)

llt_m1_noconcult<-update(llt_m1, .~. - condition_contrast:culture_contrast)
anova(llt_m1,llt_m1_noconcult)

llt_m1_noconpersp<-update(llt_m1, .~. - condition_contrast:persp_contrast)
anova(llt_m1,llt_m1_noconpersp) 

llt_m1_noperspcult<-update(llt_m1, .~. - persp_contrast:culture_contrast)
anova(llt_m1,llt_m1_noperspcult)

llt_m1_no3way<-update(llt_m1, .~. - condition_contrast:culture_contrast:persp_contrast)
anova(llt_m1,llt_m1_no3way)
BF_BIC = exp((BIC(llt_m1_no3way) - BIC(llt_m1))/2)  # BICs to Bayes factor
BF_BIC #BF10=0.0272


##ego error
egom1 = glmer(ego ~ condition_contrast*culture_contrast*persp_contrast + 
                (1+condition_contrast*persp_contrast|subject) + 
                (1+condition_contrast*culture_contrast|item), 
              family=binomial(link="logit"),
              data = s3data_stats,
              control=glmerControl(optimizer="bobyqa")) #not converge

egom2 = glmer(ego ~ condition_contrast*culture_contrast*persp_contrast + 
                (1+condition_contrast*persp_contrast||subject) + 
                (1+condition_contrast*culture_contrast||item), 
              family=binomial(link="logit"),
              data = s3data_stats,
              control=glmerControl(optimizer="bobyqa")) #converges after uncorrelating variables
summary(egom2) #condition:culture|item accounts for smallest amount of variance, so removed

egom3 = glmer(ego ~ condition_contrast*culture_contrast*persp_contrast + 
                (1+condition_contrast*persp_contrast|subject) + 
                (1+condition_contrast+culture_contrast|item), 
              family=binomial(link="logit"),
              data = s3data_stats,
              control=glmerControl(optimizer="bobyqa")) #not converge, further remove culture|item as accounts for smallest amount of variance

egom4 = glmer(ego ~ condition_contrast*culture_contrast*persp_contrast + 
                (1+condition_contrast*persp_contrast|subject) + 
                (1+condition_contrast|item), 
              family=binomial(link="logit"),
              data = s3data_stats,
              control=glmerControl(optimizer="bobyqa")) #not converge, further remove condition|subject as account for smallest variance

egom5 = glmer(ego ~ condition_contrast*culture_contrast*persp_contrast + 
                (1+persp_contrast+persp_contrast:condition_contrast|subject) + 
                (1+condition_contrast|item), 
              family=binomial(link="logit"),
              data = s3data_stats,
              control=glmerControl(optimizer="bobyqa")) #not converge, further remove persp*condition|subject as account for smallest variance

egom6 = glmer(ego ~ condition_contrast*culture_contrast*persp_contrast + 
                (1+persp_contrast|subject) + 
                (1+condition_contrast|item), 
              family=binomial(link="logit"),
              data = s3data_stats,
              control=glmerControl(optimizer="bobyqa")) #not converge, further remove condition|item as account for smallest variance

#ego error from experimental trials only
data_exp<-subset(s3data_stats, condition=="exp", drop = FALSE)
head(data_exp,5)

expegom1 = glmer(ego ~ culture_contrast*persp_contrast + 
                (1+persp_contrast|subject) + 
                (1+culture_contrast|item), 
              family=binomial(link="logit"),
              data = data_exp,
              control=glmerControl(optimizer="bobyqa")) #converges
summary(expegom1)

expegom1_nocult<-update(expegom1, .~. - culture_contrast)
anova(expegom1,expegom1_nocult)

expegom1_nopersp<-update(expegom1, .~. - persp_contrast)
anova(expegom1,expegom1_nopersp)

expegom1_noperspcult<-update(expegom1, .~. - culture_contrast:persp_contrast)
anova(expegom1,expegom1_noperspcult) 

BF_BIC = exp((BIC(expegom1_noperspcult) - BIC(expegom1))/2)  #BICs to Bayes factor
BF_BIC #BF10=0.0321


##fixation on distractor on correct trials
distrafixm1 = glmer(distrafix ~ condition_contrast*culture_contrast*persp_contrast + 
                      (1+condition_contrast*persp_contrast|subject) + 
                      (1+condition_contrast*culture_contrast|item), 
                    family=binomial(link="logit"),
                    data = data_acc_corr,
                    control=glmerControl(optimizer="bobyqa"))
summary(distrafixm1)

distrafixm1_nocon<-update(distrafixm1, .~. -condition_contrast)
anova(distrafixm1,distrafixm1_nocon) 

distrafixm1_nocult<-update(distrafixm1, .~. -culture_contrast)
anova(distrafixm1,distrafixm1_nocult)

distrafixm1_nopersp<-update(distrafixm1, .~. -persp_contrast)
anova(distrafixm1,distrafixm1_nopersp)

distrafixm1_noconcult<-update(distrafixm1, .~. -condition_contrast:culture_contrast)
anova(distrafixm1,distrafixm1_noconcult) 

distrafixm1_noconpersp<-update(distrafixm1, .~. -condition_contrast:persp_contrast)
anova(distrafixm1,distrafixm1_noconpersp)

distrafixm1_noperspcult<-update(distrafixm1, .~. -persp_contrast:culture_contrast)
anova(distrafixm1,distrafixm1_noperspcult) 

distrafixm1_no3way<-update(distrafixm1, .~. -condition_contrast:culture_contrast:persp_contrast)
anova(distrafixm1,distrafixm1_no3way) 
BF_BIC = exp((BIC(distrafixm1_no3way) - BIC(distrafixm1))/2)
BF_BIC #BF10
